@@ -30,13 +30,34 @@ class FabrikWriteRequest(pydantic.BaseModel):
 
     df: pd.DataFrame
     path: str
+    warehouse: str
     mode: str = "auto"
 
 
+class FabrikRawWriteRequest(pydantic.BaseModel):
+    path: str
+    warehouse: str
+    format: str = "parquet"
+    context: typing.Dict[str, str] = None
+
+
 class FabrikWriteResponse(pydantic.BaseModel):
-    pass
+    reference: str
 
 
 class FabrikRawReadResponse(pydantic.BaseModel):
     format: str
     context: typing.Dict[Any, Any]
+
+
+class FabrikRawWriteResponse(pydantic.BaseModel):
+    reference: str
+
+
+class FabrikRawWriteProfileRequest(pydantic.BaseModel):
+    reference: str
+
+
+class FabrikRawWriteProfileResponse(pydantic.BaseModel):
+    kind: str
+    context: typing.Dict[Any, Any]
